==> nektar%2B%2B-5.1.0.tar.bz2: nektar-v5.1.0/library/LocalRegions/LinSys.hpp <==
///////////////////////////////////////////////////////////////////////////////
//
// File LinSysKey.hpp
//
// For more information, please see: http://www.nektar.info
//
// The MIT License
//
// Copyright (c) 2006 Division of Applied Mathematics, Brown University (USA),
// Department of Aeronautics, Imperial College London (UK), and Scientific
// Computing and Imaging Institute, University of Utah (USA).
//
// Permission is hereby granted, free of charge, to any person obtaining a
// copy of this software and associated documentation files (the "Software"),
// to deal in the Software without restriction, including without limitation
// the rights to use, copy, modify, merge, publish, distribute, sublicense,
// and/or sell copies of the Software, and to permit persons to whom the
// Software is furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included
// in all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
// OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
// THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
// FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
// DEALINGS IN THE SOFTWARE.
//
// Description: Headers/definitions of LinSysKey
//
///////////////////////////////////////////////////////////////////////////////

#ifndef LINSYSKEY_HPP
#define LINSYSKEY_HPP


#include <StdRegions/StdRegions.hpp>
#include <StdRegions/StdMatrixKey.h>

namespace Nektar
{
    namespace LocalRegions
    {
    
        class LinSysKey: public MatrixKey
        {  
        public:
            LinSysKey(StdRegions::MatrixType matrixType, StdRegions::ExpansionType expansionType, 
              StdRegions::StdExpansion &stdExpansion):
        MatrixKey(matrixType,expansionType,stdExpansion)
        {
                }
        
            virtual ~LinSysKey()
            {
            }
        
        private:
        
        };

    } // end of namespace
} // end of namespace

#endif //LINSYSKEY_HPP

==> nektar%2B%2B-5.8.0.tar.bz2: nektar-v5.8.0/library/LocalRegions/LinSys.hpp <==
///////////////////////////////////////////////////////////////////////////////
//
// File: LinSys.hpp
//
// For more information, please see: http://www.nektar.info
//
// The MIT License
//
// Copyright (c) 2006 Division of Applied Mathematics, Brown University (USA),
// Department of Aeronautics, Imperial College London (UK), and Scientific
// Computing and Imaging Institute, University of Utah (USA).
//
// Permission is hereby granted, free of charge, to any person obtaining a
// copy of this software and associated documentation files (the "Software"),
// to deal in the Software without restriction, including without limitation
// the rights to use, copy, modify, merge, publish, distribute, sublicense,
// and/or sell copies of the Software, and to permit persons to whom the
// Software is furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included
// in all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
// OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
// THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
// FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
// DEALINGS IN THE SOFTWARE.
//
// Description: Headers/definitions of LinSys
//
///////////////////////////////////////////////////////////////////////////////

#ifndef LINSYSKEY_HPP
#define LINSYSKEY_HPP

#include <StdRegions/StdMatrixKey.h>
#include <StdRegions/StdRegions.hpp>

namespace Nektar
{
namespace LocalRegions
{

class LinSysKey : public MatrixKey
{
public:
    LinSysKey(StdRegions::MatrixType matrixType,
              StdRegions::ExpansionType expansionType,
              StdRegions::StdExpansion &stdExpansion)
        : MatrixKey(matrixType, expansionType, stdExpansion)
    {
    }

    virtual ~LinSysKey()
    {
    }

private:
};

} // namespace LocalRegions
} // namespace Nektar

#endif // LINSYSKEY_HPP
